You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by cd...@apache.org on 2024/02/20 18:37:10 UTC

(camel-k) branch main updated: Move KameletRepositorySpec to common types

This is an automated email from the ASF dual-hosted git repository.

cdeppisch pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel-k.git


The following commit(s) were added to refs/heads/main by this push:
     new 52d184434 Move KameletRepositorySpec to common types
52d184434 is described below

commit 52d1844346776c7778d34a7846839df95283d2ab
Author: Christoph Deppisch <cd...@redhat.com>
AuthorDate: Tue Feb 20 09:52:15 2024 +0100

    Move KameletRepositorySpec to common types
    
    The spec may be used by other types in the future, too
---
 docs/modules/ROOT/partials/apis/camel-k-crds.adoc  | 52 +++++++++++-----------
 docs/modules/ROOT/partials/apis/crds-html.adoc     |  8 ++--
 helm/camel-k/crds/crd-integration-platform.yaml    | 12 ++---
 pkg/apis/camel/v1/common_types.go                  |  6 +++
 pkg/apis/camel/v1/integrationplatform_types.go     | 10 +----
 pkg/apis/camel/v1/zz_generated.deepcopy.go         | 32 ++++++-------
 .../camel/v1/integrationplatformkameletspec.go     |  4 +-
 ...trepositoryspec.go => kameletrepositoryspec.go} | 12 ++---
 pkg/client/camel/applyconfiguration/utils.go       |  4 +-
 pkg/cmd/kamelet_add_repo.go                        |  4 +-
 pkg/cmd/kamelet_add_repo_test.go                   |  6 +--
 pkg/cmd/kamelet_remove_repo.go                     |  2 +-
 pkg/cmd/kamelet_remove_repo_test.go                |  6 +--
 pkg/kamelet/repository/repository_test.go          |  4 +-
 pkg/platform/defaults.go                           |  2 +-
 .../camel.apache.org_integrationplatforms.yaml     | 12 ++---
 16 files changed, 88 insertions(+), 88 deletions(-)

diff --git a/docs/modules/ROOT/partials/apis/camel-k-crds.adoc b/docs/modules/ROOT/partials/apis/camel-k-crds.adoc
index 1d504da9a..493639117 100644
--- a/docs/modules/ROOT/partials/apis/camel-k-crds.adoc
+++ b/docs/modules/ROOT/partials/apis/camel-k-crds.adoc
@@ -2694,7 +2694,7 @@ string
 
 
 a base image that can be used as base layer for all images.
-It can be useful if you want to provide some custom base image with further utility softwares
+It can be useful if you want to provide some custom base image with further utility software
 
 |`registry` +
 *xref:#_camel_apache_org_v1_RegistrySpec[RegistrySpec]*
@@ -2821,30 +2821,6 @@ A human-readable message indicating details about the transition.
 IntegrationPlatformConditionType defines the type of condition.
 
 
-[#_camel_apache_org_v1_IntegrationPlatformKameletRepositorySpec]
-=== IntegrationPlatformKameletRepositorySpec
-
-*Appears on:*
-
-* <<#_camel_apache_org_v1_IntegrationPlatformKameletSpec, IntegrationPlatformKameletSpec>>
-
-IntegrationPlatformKameletRepositorySpec defines the location of the Kamelet catalog to use.
-
-[cols="2,2a",options="header"]
-|===
-|Field
-|Description
-
-|`uri` +
-string
-|
-
-
-the remote repository in the format github:ORG/REPO/PATH_TO_KAMELETS_FOLDER
-
-
-|===
-
 [#_camel_apache_org_v1_IntegrationPlatformKameletSpec]
 === IntegrationPlatformKameletSpec
 
@@ -2860,7 +2836,7 @@ IntegrationPlatformKameletSpec define the behavior for all the Kamelets controll
 |Description
 
 |`repositories` +
-*xref:#_camel_apache_org_v1_IntegrationPlatformKameletRepositorySpec[[\]IntegrationPlatformKameletRepositorySpec]*
+*xref:#_camel_apache_org_v1_KameletRepositorySpec[[\]KameletRepositorySpec]*
 |
 
 
@@ -3722,6 +3698,30 @@ string
 the default value of the property (if any)
 
 
+|===
+
+[#_camel_apache_org_v1_KameletRepositorySpec]
+=== KameletRepositorySpec
+
+*Appears on:*
+
+* <<#_camel_apache_org_v1_IntegrationPlatformKameletSpec, IntegrationPlatformKameletSpec>>
+
+KameletRepositorySpec defines the location of the Kamelet catalog to use.
+
+[cols="2,2a",options="header"]
+|===
+|Field
+|Description
+
+|`uri` +
+string
+|
+
+
+the remote repository in the format github:ORG/REPO/PATH_TO_KAMELETS_FOLDER
+
+
 |===
 
 [#_camel_apache_org_v1_KameletSpec]
diff --git a/docs/modules/ROOT/partials/apis/crds-html.adoc b/docs/modules/ROOT/partials/apis/crds-html.adoc
index 53fc8c68d..c00bf43ab 100644
--- a/docs/modules/ROOT/partials/apis/crds-html.adoc
+++ b/docs/modules/ROOT/partials/apis/crds-html.adoc
@@ -2818,14 +2818,14 @@ string
 <div>
 <p>IntegrationPlatformConditionType &ndash;</p>
 </div>
-<h3 id="camel.apache.org/v1.IntegrationPlatformKameletRepositorySpec">IntegrationPlatformKameletRepositorySpec
+<h3 id="camel.apache.org/v1.KameletRepositorySpec">KameletRepositorySpec
 </h3>
 <p>
 (<em>Appears on:</em>
 <a href="#camel.apache.org/v1.IntegrationPlatformKameletSpec">IntegrationPlatformKameletSpec</a>)
 </p>
 <div>
-<p>IntegrationPlatformKameletRepositorySpec &ndash;</p>
+<p>KameletRepositorySpec &ndash;</p>
 </div>
 <table>
 <thead>
@@ -2868,8 +2868,8 @@ string
 <td>
 <code>repositories</code><br/>
 <em>
-<a href="#camel.apache.org/v1.IntegrationPlatformKameletRepositorySpec">
-[]IntegrationPlatformKameletRepositorySpec
+<a href="#camel.apache.org/v1.KameletRepositorySpec">
+[]KameletRepositorySpec
 </a>
 </em>
 </td>
diff --git a/helm/camel-k/crds/crd-integration-platform.yaml b/helm/camel-k/crds/crd-integration-platform.yaml
index 703421ce0..9c910de12 100644
--- a/helm/camel-k/crds/crd-integration-platform.yaml
+++ b/helm/camel-k/crds/crd-integration-platform.yaml
@@ -95,7 +95,7 @@ spec:
                   baseImage:
                     description: a base image that can be used as base layer for all
                       images. It can be useful if you want to provide some custom
-                      base image with further utility softwares
+                      base image with further utility software
                     type: string
                   buildCatalogToolTimeout:
                     description: 'the timeout (in seconds) to use when creating the
@@ -434,8 +434,8 @@ spec:
                   repositories:
                     description: remote repository used to retrieve Kamelet catalog
                     items:
-                      description: IntegrationPlatformKameletRepositorySpec defines
-                        the location of the Kamelet catalog to use.
+                      description: KameletRepositorySpec defines the location of the
+                        Kamelet catalog to use.
                       properties:
                         uri:
                           description: the remote repository in the format github:ORG/REPO/PATH_TO_KAMELETS_FOLDER
@@ -1915,7 +1915,7 @@ spec:
                   baseImage:
                     description: a base image that can be used as base layer for all
                       images. It can be useful if you want to provide some custom
-                      base image with further utility softwares
+                      base image with further utility software
                     type: string
                   buildCatalogToolTimeout:
                     description: 'the timeout (in seconds) to use when creating the
@@ -2294,8 +2294,8 @@ spec:
                   repositories:
                     description: remote repository used to retrieve Kamelet catalog
                     items:
-                      description: IntegrationPlatformKameletRepositorySpec defines
-                        the location of the Kamelet catalog to use.
+                      description: KameletRepositorySpec defines the location of the
+                        Kamelet catalog to use.
                       properties:
                         uri:
                           description: the remote repository in the format github:ORG/REPO/PATH_TO_KAMELETS_FOLDER
diff --git a/pkg/apis/camel/v1/common_types.go b/pkg/apis/camel/v1/common_types.go
index fdcd68324..24e57130c 100644
--- a/pkg/apis/camel/v1/common_types.go
+++ b/pkg/apis/camel/v1/common_types.go
@@ -105,6 +105,12 @@ var BuildOrderStrategies = []BuildOrderStrategy{
 	BuildOrderStrategySequential,
 }
 
+// KameletRepositorySpec defines the location of the Kamelet catalog to use.
+type KameletRepositorySpec struct {
+	// the remote repository in the format github:ORG/REPO/PATH_TO_KAMELETS_FOLDER
+	URI string `json:"uri,omitempty"`
+}
+
 // ConfigurationSpec represents a generic configuration specification.
 type ConfigurationSpec struct {
 	// represents the type of configuration, ie: property, configmap, secret, ...
diff --git a/pkg/apis/camel/v1/integrationplatform_types.go b/pkg/apis/camel/v1/integrationplatform_types.go
index 6e480d3fa..67707a4db 100644
--- a/pkg/apis/camel/v1/integrationplatform_types.go
+++ b/pkg/apis/camel/v1/integrationplatform_types.go
@@ -120,7 +120,7 @@ type IntegrationPlatformBuildSpec struct {
 	// the runtime used. Likely Camel Quarkus (we used to have main runtime which has been discontinued since version 1.5)
 	RuntimeProvider RuntimeProvider `json:"runtimeProvider,omitempty"`
 	// a base image that can be used as base layer for all images.
-	// It can be useful if you want to provide some custom base image with further utility softwares
+	// It can be useful if you want to provide some custom base image with further utility software
 	BaseImage string `json:"baseImage,omitempty"`
 	// the image registry used to push/pull Integration images
 	Registry RegistrySpec `json:"registry,omitempty"`
@@ -140,13 +140,7 @@ type IntegrationPlatformBuildSpec struct {
 // IntegrationPlatformKameletSpec define the behavior for all the Kamelets controller by the IntegrationPlatform.
 type IntegrationPlatformKameletSpec struct {
 	// remote repository used to retrieve Kamelet catalog
-	Repositories []IntegrationPlatformKameletRepositorySpec `json:"repositories,omitempty"`
-}
-
-// IntegrationPlatformKameletRepositorySpec defines the location of the Kamelet catalog to use.
-type IntegrationPlatformKameletRepositorySpec struct {
-	// the remote repository in the format github:ORG/REPO/PATH_TO_KAMELETS_FOLDER
-	URI string `json:"uri,omitempty"`
+	Repositories []KameletRepositorySpec `json:"repositories,omitempty"`
 }
 
 // IntegrationPlatformBuildPublishStrategy defines the strategy used to package and publish an Integration base image.
diff --git a/pkg/apis/camel/v1/zz_generated.deepcopy.go b/pkg/apis/camel/v1/zz_generated.deepcopy.go
index 8a3629a38..5cc7ccc1f 100644
--- a/pkg/apis/camel/v1/zz_generated.deepcopy.go
+++ b/pkg/apis/camel/v1/zz_generated.deepcopy.go
@@ -1446,27 +1446,12 @@ func (in *IntegrationPlatformCondition) DeepCopy() *IntegrationPlatformCondition
 	return out
 }
 
-// DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
-func (in *IntegrationPlatformKameletRepositorySpec) DeepCopyInto(out *IntegrationPlatformKameletRepositorySpec) {
-	*out = *in
-}
-
-// DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IntegrationPlatformKameletRepositorySpec.
-func (in *IntegrationPlatformKameletRepositorySpec) DeepCopy() *IntegrationPlatformKameletRepositorySpec {
-	if in == nil {
-		return nil
-	}
-	out := new(IntegrationPlatformKameletRepositorySpec)
-	in.DeepCopyInto(out)
-	return out
-}
-
 // DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
 func (in *IntegrationPlatformKameletSpec) DeepCopyInto(out *IntegrationPlatformKameletSpec) {
 	*out = *in
 	if in.Repositories != nil {
 		in, out := &in.Repositories, &out.Repositories
-		*out = make([]IntegrationPlatformKameletRepositorySpec, len(*in))
+		*out = make([]KameletRepositorySpec, len(*in))
 		copy(*out, *in)
 	}
 }
@@ -1932,6 +1917,21 @@ func (in *KameletProperty) DeepCopy() *KameletProperty {
 	return out
 }
 
+// DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
+func (in *KameletRepositorySpec) DeepCopyInto(out *KameletRepositorySpec) {
+	*out = *in
+}
+
+// DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KameletRepositorySpec.
+func (in *KameletRepositorySpec) DeepCopy() *KameletRepositorySpec {
+	if in == nil {
+		return nil
+	}
+	out := new(KameletRepositorySpec)
+	in.DeepCopyInto(out)
+	return out
+}
+
 // DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
 func (in *KameletSpec) DeepCopyInto(out *KameletSpec) {
 	*out = *in
diff --git a/pkg/client/camel/applyconfiguration/camel/v1/integrationplatformkameletspec.go b/pkg/client/camel/applyconfiguration/camel/v1/integrationplatformkameletspec.go
index 9f02ea351..71ae00a4d 100644
--- a/pkg/client/camel/applyconfiguration/camel/v1/integrationplatformkameletspec.go
+++ b/pkg/client/camel/applyconfiguration/camel/v1/integrationplatformkameletspec.go
@@ -22,7 +22,7 @@ package v1
 // IntegrationPlatformKameletSpecApplyConfiguration represents an declarative configuration of the IntegrationPlatformKameletSpec type for use
 // with apply.
 type IntegrationPlatformKameletSpecApplyConfiguration struct {
-	Repositories []IntegrationPlatformKameletRepositorySpecApplyConfiguration `json:"repositories,omitempty"`
+	Repositories []KameletRepositorySpecApplyConfiguration `json:"repositories,omitempty"`
 }
 
 // IntegrationPlatformKameletSpecApplyConfiguration constructs an declarative configuration of the IntegrationPlatformKameletSpec type for use with
@@ -34,7 +34,7 @@ func IntegrationPlatformKameletSpec() *IntegrationPlatformKameletSpecApplyConfig
 // WithRepositories adds the given value to the Repositories field in the declarative configuration
 // and returns the receiver, so that objects can be build by chaining "With" function invocations.
 // If called multiple times, values provided by each call will be appended to the Repositories field.
-func (b *IntegrationPlatformKameletSpecApplyConfiguration) WithRepositories(values ...*IntegrationPlatformKameletRepositorySpecApplyConfiguration) *IntegrationPlatformKameletSpecApplyConfiguration {
+func (b *IntegrationPlatformKameletSpecApplyConfiguration) WithRepositories(values ...*KameletRepositorySpecApplyConfiguration) *IntegrationPlatformKameletSpecApplyConfiguration {
 	for i := range values {
 		if values[i] == nil {
 			panic("nil value passed to WithRepositories")
diff --git a/pkg/client/camel/applyconfiguration/utils.go b/pkg/client/camel/applyconfiguration/utils.go
index 3ce316c0e..3c11cd190 100644
--- a/pkg/client/camel/applyconfiguration/utils.go
+++ b/pkg/client/camel/applyconfiguration/utils.go
@@ -124,8 +124,6 @@ func ForKind(kind schema.GroupVersionKind) interface{} {
 		return &camelv1.IntegrationPlatformBuildSpecApplyConfiguration{}
 	case v1.SchemeGroupVersion.WithKind("IntegrationPlatformCondition"):
 		return &camelv1.IntegrationPlatformConditionApplyConfiguration{}
-	case v1.SchemeGroupVersion.WithKind("IntegrationPlatformKameletRepositorySpec"):
-		return &camelv1.IntegrationPlatformKameletRepositorySpecApplyConfiguration{}
 	case v1.SchemeGroupVersion.WithKind("IntegrationPlatformKameletSpec"):
 		return &camelv1.IntegrationPlatformKameletSpecApplyConfiguration{}
 	case v1.SchemeGroupVersion.WithKind("IntegrationPlatformSpec"):
@@ -150,6 +148,8 @@ func ForKind(kind schema.GroupVersionKind) interface{} {
 		return &camelv1.KameletConditionApplyConfiguration{}
 	case v1.SchemeGroupVersion.WithKind("KameletProperty"):
 		return &camelv1.KameletPropertyApplyConfiguration{}
+	case v1.SchemeGroupVersion.WithKind("KameletRepositorySpec"):
+		return &camelv1.KameletRepositorySpecApplyConfiguration{}
 	case v1.SchemeGroupVersion.WithKind("KameletSpec"):
 		return &camelv1.KameletSpecApplyConfiguration{}
 	case v1.SchemeGroupVersion.WithKind("KameletStatus"):
diff --git a/pkg/cmd/kamelet_add_repo.go b/pkg/cmd/kamelet_add_repo.go
index 5f0173143..e72b4d074 100644
--- a/pkg/cmd/kamelet_add_repo.go
+++ b/pkg/cmd/kamelet_add_repo.go
@@ -93,7 +93,7 @@ func (o *kameletAddRepoCommandOptions) run(cmd *cobra.Command, args []string) er
 		if err := checkURI(uri, platform.Spec.Kamelet.Repositories); err != nil {
 			return err
 		}
-		platform.Spec.Kamelet.Repositories = append(platform.Spec.Kamelet.Repositories, v1.IntegrationPlatformKameletRepositorySpec{
+		platform.Spec.Kamelet.Repositories = append(platform.Spec.Kamelet.Repositories, v1.KameletRepositorySpec{
 			URI: uri,
 		})
 	}
@@ -134,7 +134,7 @@ func (o *kameletUpdateRepoCommandOptions) findIntegrationPlatform(cmd *cobra.Com
 	return nil, nil
 }
 
-func checkURI(uri string, repositories []v1.IntegrationPlatformKameletRepositorySpec) error {
+func checkURI(uri string, repositories []v1.KameletRepositorySpec) error {
 	if !kameletRepositoryURIRegexp.MatchString(uri) {
 		return fmt.Errorf("malformed Kamelet repository uri %s, the expected format is github:owner/repo[/path_to_kamelets_folder][@version]", uri)
 	}
diff --git a/pkg/cmd/kamelet_add_repo_test.go b/pkg/cmd/kamelet_add_repo_test.go
index 3e8895a15..6ce719919 100644
--- a/pkg/cmd/kamelet_add_repo_test.go
+++ b/pkg/cmd/kamelet_add_repo_test.go
@@ -67,7 +67,7 @@ func TestKameletAddRepoNonExistingFlag(t *testing.T) {
 }
 
 func TestKameletAddRepoInvalidRepositoryURI(t *testing.T) {
-	repositories := []v1.IntegrationPlatformKameletRepositorySpec{}
+	repositories := []v1.KameletRepositorySpec{}
 	assert.NotNil(t, checkURI("foo", repositories))
 	assert.NotNil(t, checkURI("github", repositories))
 	assert.NotNil(t, checkURI("github:", repositories))
@@ -76,7 +76,7 @@ func TestKameletAddRepoInvalidRepositoryURI(t *testing.T) {
 }
 
 func TestKameletAddRepoValidRepositoryURI(t *testing.T) {
-	repositories := []v1.IntegrationPlatformKameletRepositorySpec{}
+	repositories := []v1.KameletRepositorySpec{}
 	assert.Nil(t, checkURI("github:foo/bar", repositories))
 	assert.Nil(t, checkURI("github:foo/bar/some/path", repositories))
 	assert.Nil(t, checkURI("github:foo/bar@1.0", repositories))
@@ -84,7 +84,7 @@ func TestKameletAddRepoValidRepositoryURI(t *testing.T) {
 }
 
 func TestKameletAddRepoDuplicateRepositoryURI(t *testing.T) {
-	repositories := []v1.IntegrationPlatformKameletRepositorySpec{{URI: "github:foo/bar"}}
+	repositories := []v1.KameletRepositorySpec{{URI: "github:foo/bar"}}
 	assert.NotNil(t, checkURI("github:foo/bar", repositories))
 	assert.Nil(t, checkURI("github:foo/bar2", repositories))
 }
diff --git a/pkg/cmd/kamelet_remove_repo.go b/pkg/cmd/kamelet_remove_repo.go
index bb479dde2..4ee189042 100644
--- a/pkg/cmd/kamelet_remove_repo.go
+++ b/pkg/cmd/kamelet_remove_repo.go
@@ -88,7 +88,7 @@ func (o *kameletRemoveRepoCommandOptions) run(cmd *cobra.Command, args []string)
 	return c.Update(o.Context, platform)
 }
 
-func getURIIndex(uri string, repositories []v1.IntegrationPlatformKameletRepositorySpec) (int, error) {
+func getURIIndex(uri string, repositories []v1.KameletRepositorySpec) (int, error) {
 	for i, repo := range repositories {
 		if repo.URI == uri {
 			return i, nil
diff --git a/pkg/cmd/kamelet_remove_repo_test.go b/pkg/cmd/kamelet_remove_repo_test.go
index a9453b423..10d7ce71b 100644
--- a/pkg/cmd/kamelet_remove_repo_test.go
+++ b/pkg/cmd/kamelet_remove_repo_test.go
@@ -67,19 +67,19 @@ func TestKameletRemoveRepoNonExistingFlag(t *testing.T) {
 }
 
 func TestKameletRemoveRepoURINotFoundEmpty(t *testing.T) {
-	repositories := []v1.IntegrationPlatformKameletRepositorySpec{}
+	repositories := []v1.KameletRepositorySpec{}
 	_, err := getURIIndex("foo", repositories)
 	assert.NotNil(t, err)
 }
 
 func TestKameletRemoveRepoURINotFoundNotEmpty(t *testing.T) {
-	repositories := []v1.IntegrationPlatformKameletRepositorySpec{{URI: "github:foo/bar"}}
+	repositories := []v1.KameletRepositorySpec{{URI: "github:foo/bar"}}
 	_, err := getURIIndex("foo", repositories)
 	assert.NotNil(t, err)
 }
 
 func TestKameletRemoveRepoURIFound(t *testing.T) {
-	repositories := []v1.IntegrationPlatformKameletRepositorySpec{{URI: "github:foo/bar1"}, {URI: "github:foo/bar2"}, {URI: "github:foo/bar3"}}
+	repositories := []v1.KameletRepositorySpec{{URI: "github:foo/bar1"}, {URI: "github:foo/bar2"}, {URI: "github:foo/bar3"}}
 	i, err := getURIIndex("github:foo/bar2", repositories)
 	assert.Nil(t, err)
 	assert.Equal(t, 1, i)
diff --git a/pkg/kamelet/repository/repository_test.go b/pkg/kamelet/repository/repository_test.go
index 7bd6c2a68..6bb40c383 100644
--- a/pkg/kamelet/repository/repository_test.go
+++ b/pkg/kamelet/repository/repository_test.go
@@ -190,9 +190,9 @@ func createTestContext(uris ...string) []runtime.Object {
 		},
 	}
 	if len(uris) > 0 {
-		repos := make([]v1.IntegrationPlatformKameletRepositorySpec, 0, len(uris))
+		repos := make([]v1.KameletRepositorySpec, 0, len(uris))
 		for _, uri := range uris {
-			repos = append(repos, v1.IntegrationPlatformKameletRepositorySpec{
+			repos = append(repos, v1.KameletRepositorySpec{
 				URI: uri,
 			})
 		}
diff --git a/pkg/platform/defaults.go b/pkg/platform/defaults.go
index 67e2d3415..61b527829 100644
--- a/pkg/platform/defaults.go
+++ b/pkg/platform/defaults.go
@@ -358,7 +358,7 @@ func setPlatformDefaults(p *v1.IntegrationPlatform, verbose bool) error {
 
 	if len(p.Status.Kamelet.Repositories) == 0 {
 		log.Debugf("Integration Platform %s [%s]: setting kamelet repositories", p.Name, p.Namespace)
-		p.Status.Kamelet.Repositories = append(p.Status.Kamelet.Repositories, v1.IntegrationPlatformKameletRepositorySpec{
+		p.Status.Kamelet.Repositories = append(p.Status.Kamelet.Repositories, v1.KameletRepositorySpec{
 			URI: repository.DefaultRemoteRepository,
 		})
 	}
diff --git a/pkg/resources/config/crd/bases/camel.apache.org_integrationplatforms.yaml b/pkg/resources/config/crd/bases/camel.apache.org_integrationplatforms.yaml
index 703421ce0..9c910de12 100644
--- a/pkg/resources/config/crd/bases/camel.apache.org_integrationplatforms.yaml
+++ b/pkg/resources/config/crd/bases/camel.apache.org_integrationplatforms.yaml
@@ -95,7 +95,7 @@ spec:
                   baseImage:
                     description: a base image that can be used as base layer for all
                       images. It can be useful if you want to provide some custom
-                      base image with further utility softwares
+                      base image with further utility software
                     type: string
                   buildCatalogToolTimeout:
                     description: 'the timeout (in seconds) to use when creating the
@@ -434,8 +434,8 @@ spec:
                   repositories:
                     description: remote repository used to retrieve Kamelet catalog
                     items:
-                      description: IntegrationPlatformKameletRepositorySpec defines
-                        the location of the Kamelet catalog to use.
+                      description: KameletRepositorySpec defines the location of the
+                        Kamelet catalog to use.
                       properties:
                         uri:
                           description: the remote repository in the format github:ORG/REPO/PATH_TO_KAMELETS_FOLDER
@@ -1915,7 +1915,7 @@ spec:
                   baseImage:
                     description: a base image that can be used as base layer for all
                       images. It can be useful if you want to provide some custom
-                      base image with further utility softwares
+                      base image with further utility software
                     type: string
                   buildCatalogToolTimeout:
                     description: 'the timeout (in seconds) to use when creating the
@@ -2294,8 +2294,8 @@ spec:
                   repositories:
                     description: remote repository used to retrieve Kamelet catalog
                     items:
-                      description: IntegrationPlatformKameletRepositorySpec defines
-                        the location of the Kamelet catalog to use.
+                      description: KameletRepositorySpec defines the location of the
+                        Kamelet catalog to use.
                       properties:
                         uri:
                           description: the remote repository in the format github:ORG/REPO/PATH_TO_KAMELETS_FOLDER
diff --git a/pkg/client/camel/applyconfiguration/camel/v1/integrationplatformkameletrepositoryspec.go b/pkg/client/camel/applyconfiguration/camel/v1/kameletrepositoryspec.go
similarity index 61%
rename from pkg/client/camel/applyconfiguration/camel/v1/integrationplatformkameletrepositoryspec.go
rename to pkg/client/camel/applyconfiguration/camel/v1/kameletrepositoryspec.go
index e82bf3ed9..62cbbee33 100644
--- a/pkg/client/camel/applyconfiguration/camel/v1/integrationplatformkameletrepositoryspec.go
+++ b/pkg/client/camel/applyconfiguration/camel/v1/kameletrepositoryspec.go
@@ -19,22 +19,22 @@ limitations under the License.
 
 package v1
 
 // IntegrationPlatformKameletRepositorySpecApplyConfiguration represents an declarative configuration of the IntegrationPlatformKameletRepositorySpec type for use
 // with apply.
-type IntegrationPlatformKameletRepositorySpecApplyConfiguration struct {
+type KameletRepositorySpecApplyConfiguration struct {
 	URI *string `json:"uri,omitempty"`
 }
 
 // IntegrationPlatformKameletRepositorySpecApplyConfiguration constructs an declarative configuration of the IntegrationPlatformKameletRepositorySpec type for use with
 // apply.
-func IntegrationPlatformKameletRepositorySpec() *IntegrationPlatformKameletRepositorySpecApplyConfiguration {
-	return &IntegrationPlatformKameletRepositorySpecApplyConfiguration{}
+func KameletRepositorySpec() *KameletRepositorySpecApplyConfiguration {
+	return &KameletRepositorySpecApplyConfiguration{}
 }
 
 // WithURI sets the URI field in the declarative configuration to the given value
 // and returns the receiver, so that objects can be built by chaining "With" function invocations.
 // If called multiple times, the URI field is set to the value of the last call.
-func (b *IntegrationPlatformKameletRepositorySpecApplyConfiguration) WithURI(value string) *IntegrationPlatformKameletRepositorySpecApplyConfiguration {
+func (b *KameletRepositorySpecApplyConfiguration) WithURI(value string) *KameletRepositorySpecApplyConfiguration {
 	b.URI = &value
 	return b
 }
@@ -19,22 +19,22 @@ limitations under the License.
 package v1
 
-// IntegrationPlatformKameletRepositorySpecApplyConfiguration represents an declarative configuration of the IntegrationPlatformKameletRepositorySpec type for use
+// KameletRepositorySpecApplyConfiguration represents an declarative configuration of the KameletRepositorySpec type for use
 // with apply.
@@ -19,22 +19,22 @@ limitations under the License.
 }
 
-// IntegrationPlatformKameletRepositorySpecApplyConfiguration constructs an declarative configuration of the IntegrationPlatformKameletRepositorySpec type for use with
+// KameletRepositorySpecApplyConfiguration constructs an declarative configuration of the KameletRepositorySpec type for use with
 // apply.